==> google_applovin_unity_ads-1.0.1.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/banner_ad/Controller.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads.banner_ad

import android.content.Context
import android.util.Log
import android.widget.FrameLayout
import com.google.android.gms.ads.AdView
import com.facebook.ads.AdView as FacebookAdView
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

class BannerAdController(
    val id: String,
    val channel: MethodChannel,
    val context: Context
) : MethodChannel.MethodCallHandler {

    var bannerAdView: FrameLayout? = null
    var adMobBannerView: AdView? = null
    var facebookBannerView: FacebookAdView? = null
    /// New native ad when loaded
    var loadRequested: ((MethodChannel.Result) -> Unit)? = null

    init {
        channel.setMethodCallHandler(this)
        Log.e("MainActivity.TAG", "BannerAdController Init")
    }

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        Log.e("onMethodCall: ", "In Controller ${call.method}")
        when (call.method) {
            "load.ads.banner" -> {
                channel.invokeMethod("loading", null)
                loadRequested?.let { it(result) }
            }
            else -> result.notImplemented()
        }
    }

}

object BannerAdControllerManager {
    private val controllers: ArrayList<BannerAdController> = arrayListOf()

    init {
        Log.e("MainActivity.TAG", "BannerAdControllerManager Init")
    }

    fun createController(id: String, binaryMessenger: BinaryMessenger, context: Context) {
        if (getController(id) == null) {
            val methodChannel = MethodChannel(binaryMessenger, id)

            Log.e("createController: ", "${methodChannel.toString()}- -----  ")
            val controller = BannerAdController(id, methodChannel, context)
            controllers.add(controller)
        }
    }

    fun getController(id: String): BannerAdController? {
        return controllers.firstOrNull { it.id == id }
    }

    fun removeController(id: String) {
        val index = controllers.indexOfFirst { it.id == id }
        if (index >= 0) controllers.removeAt(index)
    }
}

==> google_applovin_unity_ads-1.1.3.tar.gz: android/src/main/kotlin/com/btcpiyush/ads/google_applovin_unity_ads/banner_ad/Controller.kt <==
package com.btcpiyush.ads.google_applovin_unity_ads.banner_ad

import android.content.Context
import android.util.Log
import android.widget.FrameLayout
import com.applovin.sdk.AppLovinSdk
import com.google.android.gms.ads.AdView
import com.facebook.ads.AdView as FacebookAdView
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

class BannerAdController(
    val appLovinSDK: AppLovinSdk?,
    val id: String,
    val channel: MethodChannel,
    val context: Context
) : MethodChannel.MethodCallHandler {

    var bannerAdView: FrameLayout? = null
    var adMobBannerView: AdView? = null
    var facebookBannerView: FacebookAdView? = null
    /// New native ad when loaded
    var loadRequested: ((MethodChannel.Result) -> Unit)? = null

    init {
        channel.setMethodCallHandler(this)
        Log.e("MainActivity.TAG", "BannerAdController Init")
    }

    override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
        Log.e("onMethodCall: ", "In Controller ${call.method}")
        when (call.method) {
            "load.ads.banner" -> {
                channel.invokeMethod("loading", null)
                loadRequested?.let { it(result) }
            }
            else -> result.notImplemented()
        }
    }

}

object BannerAdControllerManager {
    private val controllers: ArrayList<BannerAdController> = arrayListOf()

    init {
        Log.e("MainActivity.TAG", "BannerAdControllerManager Init")
    }

    fun createController(appLovinSDK: AppLovinSdk?, id: String, binaryMessenger: BinaryMessenger, context: Context) {
        if (getController(id) == null) {
            val methodChannel = MethodChannel(binaryMessenger, id)

            Log.e("createController: ", "${methodChannel.toString()}- -----  ")
            val controller = BannerAdController(appLovinSDK, id, methodChannel, context)
            controllers.add(controller)
        }
    }

    fun getController(id: String): BannerAdController? {
        return controllers.firstOrNull { it.id == id }
    }

    fun removeController(id: String) {
        val index = controllers.indexOfFirst { it.id == id }
        if (index >= 0) controllers.removeAt(index)
    }
}
